@@ -128,8 +128,9 @@ def build_job_image(config: dict) -> str:
 
     This function handles the complete image building process:
     1. Ensures we're in the repo root
-    2. Constructs the image URI based on config
-    3. Builds the image using docker build
+    2. Cleans Docker config to avoid credential helper conflicts
+    3. Constructs the image URI based on config
+    4. Builds the image using docker build
 
     Args:
         config: Dictionary containing the configuration loaded from YAML.
@@ -146,13 +147,20 @@ def build_job_image(config: dict) -> str:
     """
     move_to_repo_root()
 
+    # Clean Docker config to avoid VS Code dev container credential helper conflicts
+    from dayhoff_tools.deployment.deploy_utils import clean_docker_config
+
+    clean_docker_config()
+
     # Get image URI
     image_uri = _build_image_uri(config)
     docker_config = config["docker"]
 
     print("\nBuilding Docker image: ", image_uri)
     print(f"Using Dockerfile: {docker_config['dockerfile']}")
-    print(f"Using shared memory: {docker_config['shared_memory']}\n")
+    print(f"Using shared memory: {docker_config['shared_memory']}")
+    platform = docker_config.get("platform", "linux/amd64")
+    print(f"Building for platform: {platform}\n")
 
     # Build the image
     build_image_command = [
@@ -163,8 +171,14 @@ def build_job_image(config: dict) -> str:
         docker_config["dockerfile"],
         "-t",
         image_uri,
-        ".",  # Use the root of the repo as image context
     ]
+
+    # Add platform specification if provided, default to linux/amd64 for cloud deployments
+    platform = docker_config.get("platform", "linux/amd64")
+    build_image_command.extend(["--platform", platform])
+
+    # Add build context
+    build_image_command.append(".")  # Use the root of the repo as image context
     subprocess.run(build_image_command, check=True)
 
     # Get and print image size
